Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1261)

Unified Diff: test/mjsunit/es6/debug-promises-uncaught-uncaught.js

Issue 262533009: Revert "Trigger exception debug event for promises at the throw site." (Closed) Base URL: https://v8.googlecode.com/svn/branches/bleeding_edge
Patch Set: Created 6 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: test/mjsunit/es6/debug-promises-uncaught-uncaught.js
diff --git a/test/mjsunit/es6/debug-promises-uncaught-uncaught.js b/test/mjsunit/es6/debug-promises-uncaught-uncaught.js
index fa97ac0d8598695a327f435d6073bdc33631ec15..ae58c628cacb7e88e29456cd6fe6ef3f7b45675c 100644
--- a/test/mjsunit/es6/debug-promises-uncaught-uncaught.js
+++ b/test/mjsunit/es6/debug-promises-uncaught-uncaught.js
@@ -6,7 +6,8 @@
// Test debug events when we only listen to uncaught exceptions and
// there is a catch handler for the exception thrown in a Promise.
// We expect an Exception debug event with a promise to be triggered.
Debug = debug.Debug;
@@ -21,7 +22,7 @@ var p = new Promise(function(resolve, reject) {
var q = p.chain(
function() {
log.push("throw");
- throw new Error("uncaught"); // event
+ throw new Error("uncaught");
});
function listener(event, exec_state, event_data, data) {
@@ -30,13 +31,12 @@ function listener(event, exec_state, event_data, data) {
if (step >= 1) return;
assertEquals(["resolve", "end main", "throw"], log);
if (event == Debug.DebugEvent.Exception) {
+ assertUnreachable();
+ } else if (event == Debug.DebugEvent.PendingExceptionInPromise) {
assertEquals(0, step);
assertEquals("uncaught", event_data.exception().message);
assertTrue(event_data.promise() instanceof Promise);
- assertEquals(q, event_data.promise());
assertTrue(event_data.uncaught());
- // Assert that the debug event is triggered at the throw site.
- assertTrue(exec_state.frame(0).sourceLineText().indexOf("// event") > 0);
step++;
}
} catch (e) {
@@ -6,7 +6,8 @@
// Test debug events when we only listen to uncaught exceptions and
// there is a catch handler for the exception thrown in a Promise.
-// We expect an Exception debug event with a promise to be triggered.
+// Expectation:
+// - only the PendingExceptionInPromise debug event is triggered.
Debug = debug.Debug;
« no previous file with comments | « test/mjsunit/es6/debug-promises-uncaught-all.js ('k') | test/mjsunit/es6/debug-promises-undefined-reject.js » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698